<?php

/**
 * Class ekomiIntegrationManager
 *
 * Handles the ekomiIntegration plugin functionalities.
 * 
 * @category   plugin
 * @package    ekomi_integration
 * @author     Sandor Barics <sbarics@ekomi.de>
 * @copyright  2015-2016 
 */
class ekomiIntegrationManager {

    var $shopId = 0;
    var $shopPassword = '';
    
    const ENABLED_VALUE = 'Y';
    const DISABLED_VALUE = 'N';

     /**
     * The URL where the order data is sent.
     */
    const URL_TO_SEND_DATA = 'https://plugins-dashboard.ekomiapps.de/api/v1/order';

    /**
     * The Url to validate shop.
     */
    const URL_GET_SETTINGS = 'https://api.ekomi.de/v3/getSettings';

    /**
     * Initializes the class properties
     * 
     * @param int    $shopId       The shop id
     * @param string $shopPassword The shop password
     */
    public function __construct($shopId, $shopPassword) {
        $this->set_shopId($shopId);
        $this->set_shopPassword($shopPassword);
    }

    /**
     * Validates the shop
     * 
     * @return boolean True if validated False otherwise
     */
    public function validateShop() {
        $apiUrl = self::URL_GET_SETTINGS;
        $apiUrl .= "?auth={$this->shopId}|{$this->shopPassword}";
        $apiUrl .= '&version=cust-1.0.0&type=request&charset=iso&app=PD-JTL-4';
        $server_output = $this->doCurl($apiUrl, 'GET');
        if ($server_output == 'Access denied') {
            return FALSE;
        } else {
            return TRUE;
        }
    }

    /**
     * Adds/Sends the order data to ekomi
     * 
     * @param int $orderId The order id
     */
    function addRecipient(Plugin $oPlugin, $orderId, $orderStatus = '') {
        $oPluginEinstellungAssoc_arr = $oPlugin->oPluginEinstellungAssoc_arr;

        require_once dirname(__DIR__) . '/includes/class.ekomi_integration.helper.php';

        $helper = ekomiIntegrationHelper::getInstance($oPlugin);
        $helper->initOrder($orderId);

        if ($oPluginEinstellungAssoc_arr['ekomi_integration_enable'] == self::ENABLED_VALUE && $oPluginEinstellungAssoc_arr['ekomi_integration_terms_and_conditions'] == self::ENABLED_VALUE) {
            if (!empty($orderStatus)) {
                $helper->setOrderStatus($orderStatus);
            }

            $orderStatus = $helper->getOrderStatus();
            $ekomiIntegrationOrderStatuses = explode(',', $oPluginEinstellungAssoc_arr['ekomi_integration_order_statuses']);

            if (in_array($orderStatus, $ekomiIntegrationOrderStatuses)) {
                $orderData = $helper->getOrderData($this->shopId, $this->shopPassword);
                return $this->sendOrderData($orderData);
            }
        }
    }

        /**
     * Makes a curl request.
     *
     * @param string $requestUrl  Api End point url.
     * @param string $requestType Api Request type.
     * @param array  $httpHeader  Header.
     * @param string $postFields  The post data to send.
     * @return mixed|string
     */
    public function doCurl($requestUrl, $requestType, $httpHeader = array(), $postFields = '')
    {
        try {
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $requestUrl);
            curl_setopt($ch, CURLOPT_HEADER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $requestType);
            if (!empty($httpHeader)) {
                curl_setopt($ch, CURLOPT_HTTPHEADER, $httpHeader);
            }

            if (!empty($postFields)) {
                curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields);
            }

            $response = curl_exec($ch);
            curl_close($ch);

            return $response;
        } catch (Exception $exception) {
            $logger = LogControl::get_instance();
            $logger->notice($exception->getMessage(), 'ekomiIntegration', 'EkomiIntegration_addrecipient', 'notice', $p_level_type = 'DEBUG NOTICE', E_USER_NOTICE);
            var_dump($exception);
            return $exception->getMessage();
        }
    }

    /**
     * Sends order data to eKomi plugins-dashboard.
     *
     * @param array $orderData
     * @return mixed
     */
    public function sendOrderData($orderData)
    {
        if (!empty($orderData)) {
            $boundary   = md5(time());
            $httpHeader = array('ContentType:multipart/form-data;boundary=' . $boundary);
            $jsonData = json_encode($orderData);
            return $this->doCurl(self::URL_TO_SEND_DATA, 'PUT', $httpHeader, $jsonData);
        }
    }

    /**
     * Sets the shop Id
     * 
     * @param int $shopId The shop Id
     */
    function set_shopId($shopId) {
        $this->shopId = $shopId;
    }

    /**
     * Sets the shop Password
     * 
     * @param string $shopPassword The shop Api Key
     */
    function set_shopPassword($shopPassword) {
        $this->shopPassword = $shopPassword;
    }

    /**
     * Gets the shop id
     * 
     * @return int The shop id
     */
    function get_shopId() {
        return $this->shopId;
    }

    /**
     * Gets the shop password
     * 
     * @return string The shop Api Key
     */
    function get_shopPassword() {
        return $this->shopPassword;
    }

}
